@@ -156,19 +156,19 @@ void IndividualMailITIPHandlerDialogDelegate::openDialog(const QString &question
     switch (action) {
     case ActionSendMessage:
         Q_EMIT setUpdate(mIncidence, attendees);
-        Q_EMIT dialogClosed(KMessageBox::Yes, mMethod, mIncidence);
+        Q_EMIT dialogClosed(KMessageBox::ButtonCode::PrimaryAction, mMethod, mIncidence);
         break;
     case ActionDontSendMessage:
-        Q_EMIT dialogClosed(KMessageBox::No, mMethod, mIncidence);
+        Q_EMIT dialogClosed(KMessageBox::ButtonCode::SecondaryAction, mMethod, mIncidence);
         break;
     default:
         switch (CalendarSupport::KCalPrefs::instance()->sendPolicy()) {
         case (CalendarSupport::KCalPrefs::InvitationPolicySend):
             Q_EMIT setUpdate(mIncidence, attendees);
-            Q_EMIT dialogClosed(KMessageBox::Yes, mMethod, mIncidence);
+            Q_EMIT dialogClosed(KMessageBox::ButtonCode::PrimaryAction, mMethod, mIncidence);
             break;
         case (CalendarSupport::KCalPrefs::InvitationPolicyDontSend):
-            Q_EMIT dialogClosed(KMessageBox::No, mMethod, mIncidence);
+            Q_EMIT dialogClosed(KMessageBox::ButtonCode::SecondaryAction, mMethod, mIncidence);
             break;
         case (CalendarSupport::KCalPrefs::InvitationPolicyAsk):
         default:
@@ -230,9 +230,9 @@ void IndividualMailITIPHandlerDialogDelegate::onDialogClosed(int result)
     if (result == QDialogButtonBox::Yes) {
         Q_EMIT setEdit(mIncidence, mDialog->editAttendees());
         Q_EMIT setUpdate(mIncidence, mDialog->updateAttendees());
-        Q_EMIT dialogClosed(KMessageBox::Yes, mMethod, mIncidence);
+        Q_EMIT dialogClosed(KMessageBox::ButtonCode::PrimaryAction, mMethod, mIncidence);
     } else {
-        Q_EMIT dialogClosed(KMessageBox::No, mMethod, mIncidence);
+        Q_EMIT dialogClosed(KMessageBox::ButtonCode::SecondaryAction, mMethod, mIncidence);
     }
 }
 
